@@ -1,5 +1,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+#include "loadprev.h"
 QString game;
 QString cfg_path="/home/user/.config/Team16/psx4m/";
 QString bios_path="/home/user/MyDocs/";
@@ -59,6 +60,22 @@ connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChange
 
 void MainWindow::rom_exec(){
 if (ui->listWidget->currentRow()!=-1){
+    if (current_core=="pcsx"){
+QDir sc("/opt/maemo/usr/games/screenshots");
+QStringList st=sc.entryList(QStringList(ui->listWidget->currentItem()->text()+".*"),QDir::NoFilter,QDir::NoSort);
+if (st.count()>1){
+    bool ok;
+    QList <int> savest;
+    foreach(QString s,st)
+        savest.append(s.split(".").last().toInt(&ok, 10));
+
+    loadPrev *pr=new loadPrev(this);
+    pr->init(current_config,current_core,roms.value(ui->listWidget->currentRow()),savest);
+    pr->show();
+    return;
+
+}
+}
 
 QProcess *myProcess = new QProcess();
 QStringList args=current_config;
